package Task::CVSMonitor;

use strict;
use vars qw{$VERSION};
BEGIN {
	$VERSION = '0.006004';
}

1;

__END__

=pod

=head1 NAME

Task::CVSMonitor - Install all the CPAN modules needed by CVS Monitor 0.6.3

=head1 DESCRIPTION

This L<Task> module installs all the dependencies for the current stable
version of CVS Monitor 0.6.3.

=head1 AUTHOR

Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>

=head1 SEE ALSO

L<Task>, L<http://ali.as/devel/cvsmonitor>

=head1 COPYRIGHT

Copyright 2005 Adam Kennedy.

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=cut
